### Videos

There and back again: a packet's tale

{video url="https://www.youtube.com/embed/WwyJGzZmBe8"}

{video url="http://player.vimeo.com/video/52320658"}

How does the internet work?

{video url="https://www.youtube.com/embed/i5oe63pOhLI"}

Totally real video

{video url="http://youtu.be/totallyrealvideo"}

How the internet works in 5 minutes

{video url="https://www.youtube.com/embed/7_LPdttKXPc"}

{video url="https://player.vimeo.com/video/94502406"}

It has English captions, but the most interesting part is what is happening in the action.

{video url="https://www.youtube.com/watch?v=_fNp37zFn9Q"}

{video url="https://vimeo.com/94502406"}